library("testthat")

test_check("prettyB")

# To rerun tests
# manage_cases()
